@@ -105,6 +105,7 @@ async def update_or_create_django_instance_from_redis_instance(
     for k, v in django_params.items():
         if k not in ['django_id', 'id']:
             new_django_params[k] = v
+    print(new_django_params)
     django_params = new_django_params
     django_instance = await sync_to_async_update_or_create_django_instance_from_redis_instance(
         django_id,
@@ -204,12 +205,14 @@ async def async_redis_dict_to_django_params(
             if django_field_data['class'] == django_models.ForeignKey:
                 foreign_key_model = django_field_data['remote_field_model']
                 redis_foreign_key_instance = redis_dict[django_field_name]
+                print(redis_foreign_key_instance)
                 if redis_foreign_key_instance not in ['null', None]:
                     django_foreign_key_instance = await update_or_create_django_instance_from_redis_instance(
                         redis_foreign_key_instance,
                         foreign_key_model,
                         cache_conf,
                     )
+                    print(django_foreign_key_instance)
                     django_params[django_field_name] = django_foreign_key_instance
                 else:
                     django_params[django_field_name] = None
