@@ -10,7 +10,7 @@ from typing import Callable
 from django.db import models as django_models
 
 from .utils import check_types, check_classes, get_ids_from_untyped_data
-from .cache import default_cache_func, django_sync_to_async_list
+from .cache import default_cache_func, django_sync_to_async_list, django_sync_to_async_get
 
 
 class RedisField:
@@ -461,7 +461,7 @@ class RedisRoot:
         else:
             cached_cache_conf = self.redis_instance.get(f'{self.prefix}:cache_confs:{django_model.__name__}')
             if cached_cache_conf:
-                cache_conf = cached_cache_conf
+                cache_conf = json.loads(cached_cache_conf)
             else:
                 cache_conf = {
                     'enabled': False,
@@ -496,7 +496,7 @@ class RedisRoot:
 
                 for django_instance in django_instances:
                     async_tasks.append(
-                        self.update_or_create_redis_instance_from_django_instance(
+                        redis_root.update_or_create_redis_instance_from_django_instance(
                             django_instance,
                             django_fields,
                             cache_conf,
@@ -896,8 +896,8 @@ class RedisRoot:
                 else:
                     redis_value = django_foreign_key_instance.id
         elif django_field.__class__ == django_models.ManyToManyField:
-            django_many_to_many_instances = django_field_value.all()
             if save_related_models:
+                django_many_to_many_instances = await django_sync_to_async_list(django_field_value.all)
                 if len(django_many_to_many_instances):
                     django_instance_model = django_many_to_many_instances[0].__class__
                     redis_value = [
@@ -1247,7 +1247,12 @@ class RedisRoot:
             }
         return updated_data
 
-    def update(self, django_model, instanes=None, return_dict=False, renew_ttl=False, new_ttl=None,
+    def _get_allowed_redis_model_params(self, params, redis_model):
+        redis_model_fields_names = redis_model.__model_data__.keys()
+        result_params = list(filter(lambda param_name: param_name in redis_model_fields_names, params.keys()))
+        return result_params
+
+    def update(self, django_model, instances=None, return_dict=False, renew_ttl=False, new_ttl=None,
                **fields_to_update):
         model = self.get_or_create_redis_model_from_django_model(django_model)
         model_name = model.__name__
@@ -1315,6 +1320,7 @@ class RedisRoot:
 
     def create(self, django_model, **params):
         redis_model = self.get_or_create_redis_model_from_django_model(django_model)
+        params = self._get_allowed_redis_model_params(redis_model, params)
         redis_instance = redis_model(redis_root=self, **params).save()
         return redis_instance
 
